# MiST

MiST is a rapid, accurate and flexible (core-genome) multi-locus sequence typing (MLST) allele caller.
It provides tools to download, index, and query schemes, as well as to construct (cg)MLST-based phylogenies.

# DOCUMENTATION

The documentation is available on the [Wiki](https://github.com/BioinformaticsPlatformWIV-ISP/MiST/wiki).

# CITATION

Bogaerts B, MiST (https://github.com/BioinformaticsPlatformWIV-ISP/MiST)
